@@ -1,4 +1,3 @@
-import pandas as pd
 import pandas_flavor as pf
 from lark import Lark, Tree, Token
 from pkg_resources import resource_string
@@ -6,11 +5,19 @@ from typing import Tuple, List, Any
 from genie_pkg import GenieException
 import numpy as np
 from dateutil.parser import parse
-
+import pandas as pd
 
 @pf.register_dataframe_accessor('dqc')
 class QualityChecker(object):
-    def __init__(self, pandas_obj):
+
+    """Monkeypatch pandas dataframe to provide quality checks."""
+
+    def __init__(self, pandas_obj: pd.DataFrame) -> None:
+        """Dataframe to work on.
+
+        Args:
+            pandas_obj (pd.DataFrame): Dataframe to apply the checks on
+        """
         self._validate(pandas_obj)
         self._obj = pandas_obj
         self.ignore_column_case = False
@@ -51,8 +58,8 @@ class QualityChecker(object):
             return True
         except ValueError:
             return False
-        
-    
+
+
     @staticmethod
     def _str_to_bool(boolstr):
         if boolstr == 'True':
@@ -82,22 +89,18 @@ class QualityChecker(object):
         else:
             if (non_null_rows.shape[0] > 0):
                 return node.data, column_name, (valid_dates.shape[0]/non_null_rows.shape[0])*100 >= pass_percent
-
-        return node.data, column_name, False
+            else:
+                return node.data, column_name, True
 
 
     def _apply_has_one_of(self, node) -> Tuple[str, Any, bool]:
         column_name = self._treat_column_name(node.children[0])
         allowed_values = [ct.value.replace("\"", "") for ct in node.children[1].children]
         unique_values = self._obj[column_name].unique()
+        ignore_case = False
+        if len(node.children) == 3:
+            ignore_case = self._str_to_bool(node.children[2].value)
 
-        if len(node.children) == 2:
-            ignore_case = False
-        else:
-            if node.children[2] == 'True':
-                ignore_case = True
-            else:
-                ignore_case = False
         if ignore_case:
             allowed_values = [v.lower() for v in allowed_values]
             unique_values = [v.lower() for v in unique_values]
@@ -115,19 +118,18 @@ class QualityChecker(object):
                 pass_percent = int(c.value)
             if c.type == 'BOOL':
                 ignore_nulls = self._str_to_bool(c.value)
-            print('here...')                
             rhs = int(node.children[3])
         elif len(node.children) == 3:
             # index 1 is "=="
             rhs = int(node.children[2])
         else:
             pass_percent = int(node.children[1])
-            ignore_nulls = node.children[2]
+            ignore_nulls = self._str_to_bool(node.children[2].value)
             # index 3 is "=="
             rhs = int(node.children[4])
 
         self._obj['length'] = self._obj[column_name].fillna('').astype(str).map(len)
-        if ignore_nulls == 'True':
+        if ignore_nulls:
             not_na_df = self._obj.replace(r'^\s*$', np.NaN, regex=True).dropna()
         else:
             not_na_df = self._obj
@@ -138,18 +140,15 @@ class QualityChecker(object):
         else:
             if (not_na_df.shape[0] > 0):
                 return node.data, column_name, (passing.shape[0]/not_na_df.shape[0])*100 >= pass_percent
-        
-        return node.data, column_name, False
+            else:
+                return node.data, column_name, True
+
 
     def _apply_has_columns(self, node) -> Tuple[str, Any, bool]:
         column_names = [ct.value.replace("\"", "") for ct in node.children[0].children]
-        if len(node.children) == 1:
-            ignore_case = False
-        else:
-            if node.children[1] == 'True':
-                ignore_case = True
-            else:
-                ignore_case = False
+        ignore_case = False
+        if len(node.children) == 2:
+            ignore_case = self._str_to_bool(node.children[1].value)
 
         if ignore_case:
             expected_columns = [c.lower() for c in column_names]
@@ -172,7 +171,7 @@ class QualityChecker(object):
         target_columns = node.children[1]
         target_columns_values = [ct.value.split("==") for ct in target_columns.children]
         cleansed_target_columns_values = [(s[0].replace("\"", "").strip(), s[1].replace("\"", "").strip()) for s in target_columns_values]
-        
+
         for c in cleansed_target_columns_values:
             unique_values = qualifying_rows[c[0]].unique()
             if not (len(unique_values) == 1 and unique_values[0] == c[1]):
@@ -212,7 +211,7 @@ class QualityChecker(object):
         except KeyError:
             return "Key error: {0} for {1}".format(c.data, c.children[0]), None, False
         except Exception as e:
-            raise GenieException(f"{c.data} has errors: {e}")    
+            raise GenieException(f"{c.data} has errors: {e}")
 
     def _apply_predicates(self, predicates) -> List[Tuple[str, Any, bool]]:
         results:List[Tuple[str, Any, bool]] = []
@@ -248,7 +247,7 @@ class QualityChecker(object):
         except Exception as e:
             return str(e), False
 
-    def run(self, check_spec, ignore_column_case=False):
+    def run(self, check_spec, ignore_column_case=False) -> List[Tuple[str, Any, bool]]:
         ast = self._parse_spec(check_spec)
         self.ignore_column_case = ignore_column_case
         if self.ignore_column_case:
